==> Zephyrus-2.17.9.11104.tar.gz: Zephyrus-2.17.9.11104/Zephyrus/template_editor/management/commands/build_tree.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: assign_templates.py 10628 2017-12-10 13:03:41Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-12-10 21:03:41 +0800 (週日, 10 十二月 2017) $
# $Revision: 10628 $

import os

from django.conf import settings
from django.core.management.base import BaseCommand

from Zephyrus.template_editor.models import Static, Template

class Command(BaseCommand):

    def handle(self, *args, **options):
        print "Delete all nodes..."
        Static.objects.all().delete()
        Template.objects.all().delete()

        self.staticPath = settings.STATICFILES_DIRS[0]
        self.templatePath = settings.TEMPLATES[0]['DIRS'][0]

        self.staticDirs = None
        if hasattr(settings, 'TEMPLATE_EDITOR_PUBLIC_STATIC'):
            self.staticDirs = settings.TEMPLATE_EDITOR_PUBLIC_STATIC

        self.templateDirs = None
        if hasattr(settings, 'TEMPLATE_EDITOR_PUBLIC_TEMPLATES'):
            self.templateDirs = settings.TEMPLATE_EDITOR_PUBLIC_TEMPLATES

        self.createNode(self.staticPath, Static)
        self.createNode(self.templatePath, Template)

    def createNode(self, path, model, parent=None):

        if self.staticPath in path:
            dirs = self.staticDirs
        else:
            dirs = self.templateDirs
        
        for f in os.listdir(path):
            filePath = os.path.join(path, f)

            if dirs:
                create = False
                for dirName in dirs:
                    if filePath.startswith(dirName):
                        if dirName in filePath:
                            create = True
                    else:
                        if filePath in dirName:
                            create = True
            else:
                create = True

            if os.path.isfile(filePath):
                if create:
                    print "Create file node: %s" % filePath
                    node = model.objects.create(
                        type='file',
                        name=f,
                        parent=parent
                    )
            else:
                if create:
                    print "Create folder node: %s" % filePath
                    node = model.objects.create(
                        type='folder',
                        name=f,
                        parent=parent
                    )
                    self.createNode(filePath, model, parent=node)

==> Zephyrus-2.18.0.11119.tar.gz: Zephyrus-2.18.0.11119/Zephyrus/template_editor/management/commands/build_tree.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: assign_templates.py 10628 2017-12-10 13:03:41Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-12-10 21:03:41 +0800 (週日, 10 十二月 2017) $
# $Revision: 10628 $

import os

from django.conf import settings
from django.core.management.base import BaseCommand

from Zephyrus.template_editor.models import Static, Template

from Zephyrus.template_editor import TEMPLATE_DIR, STATIC_DIR

class Command(BaseCommand):

    def handle(self, *args, **options):
        print "Delete all nodes..."
        Static.objects.all().delete()
        Template.objects.all().delete()

        self.staticPath = STATIC_DIR
        self.templatePath = TEMPLATE_DIR

        self.staticDirs = None
        if hasattr(settings, 'TEMPLATE_EDITOR_PUBLIC_STATIC'):
            self.staticDirs = settings.TEMPLATE_EDITOR_PUBLIC_STATIC

        self.templateDirs = None
        if hasattr(settings, 'TEMPLATE_EDITOR_PUBLIC_TEMPLATES'):
            self.templateDirs = settings.TEMPLATE_EDITOR_PUBLIC_TEMPLATES

        self.createNode(self.staticPath, Static)
        self.createNode(self.templatePath, Template)

    def createNode(self, path, model, parent=None):

        if self.staticPath in path:
            dirs = self.staticDirs
        else:
            dirs = self.templateDirs
        
        for f in os.listdir(path):
            filePath = os.path.join(path, f)

            if dirs:
                create = False
                for dirName in dirs:
                    if filePath.startswith(dirName):
                        if dirName in filePath:
                            create = True
                    else:
                        if filePath in dirName:
                            create = True
            else:
                create = True

            if os.path.isfile(filePath):
                if create:
                    print "Create file node: %s" % filePath
                    node = model.objects.create(
                        type='file',
                        name=f,
                        parent=parent
                    )
            else:
                if create:
                    print "Create folder node: %s" % filePath
                    node = model.objects.create(
                        type='folder',
                        name=f,
                        parent=parent
                    )
                    self.createNode(filePath, model, parent=node)
